summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorUli Schlachter <psychon@znc.in>2015-04-05 14:39:20 +0200
committerUli Schlachter <psychon@znc.in>2015-04-05 14:39:20 +0200
commit594120dff4d3ffa55a2bb1c70e66508c8fb33273 (patch)
tree951e421d7692dfef2b0a342058557d990e3ee352 /src
parent861fc2c169cad96056de3564c4d7550433285744 (diff)
Rename *_get_name_for_event()
Now that there are three different functions for querying information about events, there shouldn't be one which monopolizes on the "_for_event" name. Instead, the preferred API is the "_for_xcb_event" function. Signed-off-by: Uli Schlachter <psychon@znc.in>
Diffstat (limited to 'src')
-rw-r--r--src/xcb_errors.c4
-rw-r--r--src/xcb_errors.h4
2 files changed, 4 insertions, 4 deletions
diff --git a/src/xcb_errors.c b/src/xcb_errors.c
index 8e90eee..ab9837a 100644
--- a/src/xcb_errors.c
+++ b/src/xcb_errors.c
@@ -172,7 +172,7 @@ const char *xcb_errors_get_name_for_xge_event(xcb_errors_context_t *ctx,
return get_strings_entry(info->static_info->strings_xge_events, event_type);
}
-const char *xcb_errors_get_name_for_event(xcb_errors_context_t *ctx,
+const char *xcb_errors_get_name_for_core_event(xcb_errors_context_t *ctx,
uint8_t event_code, const char **extension)
{
struct extension_info_t *best = NULL;
@@ -282,5 +282,5 @@ const char *xcb_errors_get_name_for_xcb_event(xcb_errors_context_t *ctx,
xkb->major_opcode, event->pad0);
}
/* Generic case, decide only based on the response_type. */
- return xcb_errors_get_name_for_event(ctx, event->response_type, extension);
+ return xcb_errors_get_name_for_core_event(ctx, event->response_type, extension);
}
diff --git a/src/xcb_errors.h b/src/xcb_errors.h
index 378913b..1a982ce 100644
--- a/src/xcb_errors.h
+++ b/src/xcb_errors.h
@@ -87,7 +87,7 @@ const char *xcb_errors_get_name_for_minor_code(xcb_errors_context_t *ctx,
uint16_t minor_code);
/**
* Get the name corresponding to some event.
*
* @param ctx An errors context, created with @ref xcb_errors_context_new ()
* @param event_code The response_type of an event.
@@ -98,7 +98,7 @@ const char *xcb_errors_get_name_for_minor_code(xcb_errors_context_t *ctx,
* major code. This will never return NULL, but other functions in this library
* may.
*/
-const char *xcb_errors_get_name_for_event(xcb_errors_context_t *ctx,
+const char *xcb_errors_get_name_for_core_event(xcb_errors_context_t *ctx,
uint8_t event_code, const char **extension);
/**
@@ -87,7 +87,7 @@ const char *xcb_errors_get_name_for_minor_code(xcb_errors_context_t *ctx,
uint16_t minor_code);
/**
- * Get the name corresponding to some event.
+ * Get the name corresponding to some core event code.
*
* @param ctx An errors context, created with @ref xcb_errors_context_new ()